@@ -92,17 +92,7 @@ class WebServer(objects.Thread):
 			response = self.__serialize__(response.json())
 		except:
 			return r3sponse.error_response(f"Failed to serialize {response}: {response.text}")
-		if response["success"] in [True, "True", "true"]:
-			message = response["message"]
-			try:  del response["message"]
-			except: a=1
-			try:  del response["error"]
-			except: a=1
-			try:  del response["success"]
-			except: a=1
-			return r3sponse.success_response(message, response)
-		else:
-			return r3sponse.error_response(response["error"])
+		return r3sponse.safe_response(response)
 	def get(self, group=None, id=None):
 		encoded = urllib.parse.urlencode({
 			"group":group,
@@ -119,17 +109,7 @@ class WebServer(objects.Thread):
 			response = self.__serialize__(response.json())
 		except:
 			return r3sponse.error_response(f"Failed to serialize {response}: {response.text}")
-		if response["success"] in [True, "True", "true"]:
-			message = response["message"]
-			try:  del response["message"]
-			except: a=1
-			try:  del response["success"]
-			except: a=1
-			try:  del response["error"]
-			except: a=1
-			return r3sponse.success_response(message, response)
-		else:
-			return r3sponse.error_response(response["error"])
+		return r3sponse.safe_response(response)
 	def app(self):
 		app = flask.Flask(__name__)
 		cli = sys.modules['flask.cli']
